@@ -7,6 +7,7 @@ from datetime import datetime
 from getpass import getuser
 from io import StringIO
 from json import load as json_load
+from json import loads as json_loads
 from random import randint
 from typing import Dict, List, Optional, Union
 
@@ -14,6 +15,8 @@ from chevron import render as chevron_render
 from toml import load as toml_load
 
 from yd_commands.args import ARGS_PARSER
+from yd_commands.check_imports import check_jsonnet_import
+from yd_commands.config_keys import *
 from yd_commands.printing import print_error, print_log
 
 # Set up default Mustache directives
@@ -56,6 +59,15 @@ if ARGS_PARSER.mustache_subs is not None:
             exit(1)
 
 
+def add_substitutions(subs: Dict):
+    """
+    Add a dictionary of substitutions. Do not overwrite existing values.
+    """
+    global MUSTACHE_SUBSTITUTIONS
+    subs.update(MUSTACHE_SUBSTITUTIONS)
+    MUSTACHE_SUBSTITUTIONS = subs
+
+
 def simple_mustache_substitution(input_string: Optional[str]) -> Optional[str]:
     """
     Apply basic Mustache substitutions.
@@ -68,17 +80,17 @@ def simple_mustache_substitution(input_string: Optional[str]) -> Optional[str]:
     if input_string is None:
         return None
 
-    # Trap stderror to capture Chevron misses, if 'stack-trace' is specified
-    if ARGS_PARSER.stack_trace:
+    # Trap stderror to capture Chevron misses, if 'debug' is specified
+    if ARGS_PARSER.debug:
         error = StringIO()
         sys.stderr = error
 
     result = chevron_render(
-        input_string, MUSTACHE_SUBSTITUTIONS, warn=ARGS_PARSER.stack_trace
+        input_string, MUSTACHE_SUBSTITUTIONS, warn=ARGS_PARSER.debug
     )
 
     # Restore stderror and report missing substitutions
-    if ARGS_PARSER.stack_trace:
+    if ARGS_PARSER.debug:
         sys.stderr = sys.__stderr__
         error_msg = error.getvalue().rstrip()
         if error_msg != "":
@@ -149,7 +161,7 @@ def substitute_mustache_str(
     if input.startswith(f"{{{{{number_}"):
         input_var_mustache = input.replace(number_, "")
         if _remove_mustache_brackets(input_var_mustache) not in MUSTACHE_SUBSTITUTIONS:
-            if ARGS_PARSER.stack_trace:
+            if ARGS_PARSER.debug:
                 print_log(f"Note: No Mustache substitution found for '{input}'")
             return input
         replaced = simple_mustache_substitution(input_var_mustache)
@@ -168,7 +180,7 @@ def substitute_mustache_str(
     if input.startswith(f"{{{{{bool_}"):
         input_var_mustache = input.replace(bool_, "")
         if _remove_mustache_brackets(input_var_mustache) not in MUSTACHE_SUBSTITUTIONS:
-            if ARGS_PARSER.stack_trace:
+            if ARGS_PARSER.debug:
                 print_log(f"Note: No Mustache substitution found for '{input}'")
             return input
         replaced = simple_mustache_substitution(input_var_mustache)
@@ -192,9 +204,23 @@ def load_json_file_with_mustache_substitutions(filename: str, prefix: str = "")
     substitutions processed.
     """
     with open(filename, "r") as f:
-        wr_data = json_load(f)
-    process_mustache_substitutions(wr_data, prefix=prefix)
-    return wr_data
+        dict_data = json_load(f)
+    process_mustache_substitutions(dict_data, prefix=prefix)
+    return dict_data
+
+
+def load_jsonnet_file_with_mustache_substitutions(filename: str, prefix="") -> Dict:
+    """
+    Takes a JSONNET filename and returns a dictionary with its mustache
+    substitutions processed.
+    """
+
+    check_jsonnet_import()
+    from _jsonnet import evaluate_file
+
+    dict_data = json_loads(evaluate_file(filename))
+    process_mustache_substitutions(dict_data, prefix=prefix)
+    return dict_data
 
 
 def load_toml_file_with_mustache_substitutions(filename: str, prefix: str = "") -> Dict:
@@ -204,5 +230,13 @@ def load_toml_file_with_mustache_substitutions(filename: str, prefix: str = "")
     """
     with open(filename, "r") as f:
         config = toml_load(f)
+
+    # Add any Mustache substitutions in the TOML file before processing the
+    # file as a whole
+    try:
+        add_substitutions(config[COMMON_SECTION][MUSTACHE])
+    except KeyError:
+        pass
+
     process_mustache_substitutions(config, prefix=prefix)
     return config
